@@ -1,3 +1,5 @@
+from threading import Event
+
 import time
 import datetime
 from pynput.keyboard import Controller, Key, Listener
@@ -23,13 +25,16 @@ def get_target_time(time):
 
 # Stop flag
 repeat = True
+# Sleep event
+sleep = Event()
 
 
 def on_press(key):
     """Handler to mark the stop flag when ESC is pressed"""
-    global repeat
+    global repeat, sleep
     if key == Key.esc:
         repeat = False
+        sleep.set()
 
 
 listener = Listener(on_press=on_press)
@@ -39,11 +44,19 @@ listener.start()
 keyboard = Controller()
 
 
-def activity(sleep_time=10, stop_time=None):
+def activity(sleep_time=10, stop_time=None, monitor=None):
+    """
+
+    Args:
+        sleep_time (float): Time to sleep between actions.
+        stop_time (datetime.datetime): A time to stop.
+        monitor (callable): A function to call after every step.
+
+    """
     global repeat
     repeat = True
     while repeat:
-        time.sleep(sleep_time)
+        sleep.wait(sleep_time)
         if not repeat:  # If pressed during sleep
             break
 
@@ -61,3 +74,6 @@ def activity(sleep_time=10, stop_time=None):
             with keyboard.pressed(Key.shift):
                 keyboard.press(Key.tab)
                 keyboard.release(Key.tab)
+
+        if monitor is not None:
+            monitor()
